stringToInt property
Create a FieldParser for a String type to a decimal integer.
Implementation
static final stringToInt = FieldParser<String, int>(
from: String,
to: int,
parserFunction: (v) => int.tryParse(v, radix: 10),
);
Create a FieldParser for a String type to a decimal integer.
static final stringToInt = FieldParser<String, int>(
from: String,
to: int,
parserFunction: (v) => int.tryParse(v, radix: 10),
);